betty.extension.gramps package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.gramps package

## Submodules

- betty.extension.gramps.config module
  - `FamilyTreeConfiguration`
    - `FamilyTreeConfiguration.__init__()`
    - `FamilyTreeConfiguration.dump()`
    - `FamilyTreeConfiguration.file_path`
    - `FamilyTreeConfiguration.load()`
    - `FamilyTreeConfiguration.update()`
  - `FamilyTreeConfigurationSequence`
  - `GrampsConfiguration`
    - `GrampsConfiguration.__init__()`
    - `GrampsConfiguration.dump()`
    - `GrampsConfiguration.family_trees`
    - `GrampsConfiguration.load()`
    - `GrampsConfiguration.update()`
- betty.extension.gramps.gui module

## Module contents

Integrate Betty with Gramps.

class betty.extension.gramps.Gramps

  Bases: `ConfigurableExtension`[`GrampsConfiguration`], `UserFacingExtension`, `Loader`, `GuiBuilder`

  Integrate Betty with Gramps.

  Parameters:

    - args (`typing.Any`)

    - configuration (`typing.Optional`[`typing.TypeVar`(`ConfigurationT`, bound= `betty.config.Configuration`)])

    - kwargs (`typing.Any`)

  classmethod default_configuration() → betty.extension.gramps.config.GrampsConfiguration

    Get this extension’s default configuration.

    Return type:

      `betty.extension.gramps.config.GrampsConfiguration`

  classmethod description() → betty.locale.Str

    Get the human-readable extension description.

    Return type:

      `betty.locale.Str`

  gui_build() → betty.extension.gramps.gui._GrampsGuiWidget

    Build this extension’s Graphical User Interface component.

    Return type:

      `betty.extension.gramps.gui._GrampsGuiWidget`

  classmethod label() → betty.locale.Str

    Get the human-readable extension label.

    Return type:

      `betty.locale.Str`

  async load() → None

    Load ancestry data.

    Return type:

      `None`

  classmethod name() → str

    The machine name.

    Return type:

      `str`